==> qcad-3.15.5.3.tgz: lib/qcad/scripts/Edit/DrawingPreferences/DimensionSettings/ts/DimensionSettings_fi.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fi">
<context>
    <name>DimensionSettings</name>
    <message>
        <location filename="../DimensionSettings.js" line="+27"/>
        <source>Defaults for New Drawings</source>
        <translation>Oletusarvot uusille piirroksille</translation>
    </message>
    <message>
        <location line="+0"/>
        <location line="+2"/>
        <source>Dimension Settings</source>
        <translation>Mitta-asetukset</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Dimension</source>
        <translation>Mitat</translation>
    </message>
    <message>
        <location line="+107"/>
        <source>Scientific</source>
        <translation>Tieteellinen</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Decimal</source>
        <translation>Desimaalinen</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Engineering</source>
        <translation>Tekninen</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Architectural</source>
        <translation>Arkkitehtuurinen</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Fractional</source>
        <translation>Murtoluku</translation>
    </message>
    <message>
        <location line="+32"/>
        <source>Decimal Degrees</source>
        <translation>Desimaaliasteet</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Deg/min/sec</source>
        <translation>Ast/min/sek</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Gradians</source>
        <translation>Gradiaanit</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Radians</source>
        <translation>Radiaanit</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Surveyor&apos;s units</source>
        <translation>Maanmittauksen yksiköt</translation>
    </message>
    <message>
        <location line="+198"/>
        <source>Unit / Format</source>
        <translation>Yksikkö / Muoto</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>The drawing unit must be &apos;Inch&apos; or &apos;Foot&apos; to display dimension labels in formats &apos;Architectural&apos; or &apos;Engineering&apos;. Format changed to &apos;Decimal&apos;.</source>
        <translation>Piirroksen yksikkö pitää olla &apos;tuuma&apos; tai &apos;jalka&apos; jotta näytetään mittaselitteet muodossa &apos;arkkitehtuurinen&apos; tai &apos;tekninen&apos;. Muoto vaihdettu &apos;desimaaliseksi&apos;.</translation>
    </message>
    <message>
        <location filename="../PreferencesPage.ui" line="+29"/>
        <source>Sizes</source>
        <translation>Koot</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Keep proportions</source>
        <translation>Pidä mittasuhde</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Text height:</source>
        <translation>Tekstin korkeus:</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Extension line offset:</source>
        <translation>Jatkolinjan alkukohta:</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Extension line extension:</source>
        <translation>Jatkolinjan pidennys:</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Dimension line gap:</source>
        <translation>Mittaviivan väli:</translation>
    </message>
    <message>
        <location line="+24"/>
        <source>Arrow size:</source>
        <translation>Nuolen koko:</translation>
    </message>
    <message>
        <location line="+95"/>
        <source>Size scale factor:</source>
        <translation>Kokoasteikon kerroin:</translation>
    </message>
    <message>
        <location line="+38"/>
        <source>Arrow Style</source>
        <translation>Nuolen tyyli</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Arrow</source>
        <translation>Nuoli</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Architectural Tick</source>
        <translation>arkkitehtien rasti</translation>
    </message>
    <message>
        <location line="+23"/>
        <source>Font</source>
        <translation>Kirjasin</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Dimension label font:</source>
        <translation>Mittaselitteen kirjasin:</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Label Format</source>
        <translation>Selitteen muoto</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Linear Dimensions</source>
        <translation>Lineaariset mitat</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>&amp;Format:</source>
        <translation>&amp;Muotoile:</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>P&amp;recision:</source>
        <translation>Tarkkuus:</translation>
    </message>
    <message>
        <location line="+32"/>
        <location line="+60"/>
        <source>Show trailing zeros</source>
        <translation>Näytä etunollat</translation>
    </message>
    <message>
        <location line="-50"/>
        <source>Angular Dimensions</source>
        <translation>Kulmamitat</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>F&amp;ormat:</source>
        <translation>Muotoile:</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Pre&amp;cision:</source>
        <translation>Tarkkuus:</translation>
    </message>
    <message>
        <location line="+32"/>
        <location line="+19"/>
        <source>Preview</source>
        <translation>Esikatselu</translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/Edit/DrawingPreferences/DimensionSettings/ts/DimensionSettings_fi.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fi">
<context>
    <name>DimensionSettings</name>
    <message>
        <location filename="../DimensionSettings.js" line="+27"/>
        <source>Defaults for New Drawings</source>
        <translation>Oletusarvot uusille piirroksille</translation>
    </message>
    <message>
        <location line="+0"/>
        <location line="+2"/>
        <source>Dimension Settings</source>
        <translation>Mitta-asetukset</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Dimension</source>
        <translation>Mitat</translation>
    </message>
    <message>
        <location line="+108"/>
        <source>point</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <source>comma</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <source>space</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+16"/>
        <source>Scientific</source>
        <translation>Tieteellinen</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Decimal</source>
        <translation>Desimaalinen</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Engineering</source>
        <translation>Tekninen</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Architectural</source>
        <translation>Arkkitehtuurinen</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Fractional</source>
        <translation>Murtoluku</translation>
    </message>
    <message>
        <location line="+32"/>
        <source>Decimal Degrees</source>
        <translation>Desimaaliasteet</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Deg/min/sec</source>
        <translation>Ast/min/sek</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Gradians</source>
        <translation>Gradiaanit</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Radians</source>
        <translation>Radiaanit</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Surveyor&apos;s units</source>
        <translation>Maanmittauksen yksiköt</translation>
    </message>
    <message>
        <location line="+209"/>
        <source>Unit / Format</source>
        <translation>Yksikkö / Muoto</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>The drawing unit must be &apos;Inch&apos; to display dimension labels in formats &apos;Architectural&apos; or &apos;Engineering&apos;. Format changed to &apos;Decimal&apos;.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The drawing unit must be &apos;Inch&apos; or &apos;Foot&apos; to display dimension labels in formats &apos;Architectural&apos; or &apos;Engineering&apos;. Format changed to &apos;Decimal&apos;.</source>
        <translation type="vanished">Piirroksen yksikkö pitää olla &apos;tuuma&apos; tai &apos;jalka&apos; jotta näytetään mittaselitteet muodossa &apos;arkkitehtuurinen&apos; tai &apos;tekninen&apos;. Muoto vaihdettu &apos;desimaaliseksi&apos;.</translation>
    </message>
    <message>
        <location filename="../PreferencesPage.ui" line="+29"/>
        <source>Sizes</source>
        <translation>Koot</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Keep proportions</source>
        <translation>Pidä mittasuhde</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Text height:</source>
        <translation>Tekstin korkeus:</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Extension line offset:</source>
        <translation>Jatkolinjan alkukohta:</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Extension line extension:</source>
        <translation>Jatkolinjan pidennys:</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Dimension line gap:</source>
        <translation>Mittaviivan väli:</translation>
    </message>
    <message>
        <location line="+24"/>
        <source>Arrow size:</source>
        <translation>Nuolen koko:</translation>
    </message>
    <message>
        <location line="+95"/>
        <source>Size scale factor:</source>
        <translation>Kokoasteikon kerroin:</translation>
    </message>
    <message>
        <location line="+38"/>
        <source>Arrow Style</source>
        <translation>Nuolen tyyli</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Arrow</source>
        <translation>Nuoli</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Architectural Tick</source>
        <translation>arkkitehtien rasti</translation>
    </message>
    <message>
        <location line="+23"/>
        <source>Font</source>
        <translation>Kirjasin</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Dimension label font:</source>
        <translation>Mittaselitteen kirjasin:</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Number Format</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Decimal separator:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+26"/>
        <source>Label Format</source>
        <translation>Selitteen muoto</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Linear Dimensions</source>
        <translation>Lineaariset mitat</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>&amp;Format:</source>
        <translation>&amp;Muotoile:</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>P&amp;recision:</source>
        <translation>Tarkkuus:</translation>
    </message>
    <message>
        <location line="+32"/>
        <location line="+60"/>
        <source>Show trailing zeros</source>
        <translation>Näytä etunollat</translation>
    </message>
    <message>
        <location line="-50"/>
        <source>Angular Dimensions</source>
        <translation>Kulmamitat</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>F&amp;ormat:</source>
        <translation>Muotoile:</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Pre&amp;cision:</source>
        <translation>Tarkkuus:</translation>
    </message>
    <message>
        <location line="+32"/>
        <location line="+19"/>
        <source>Preview</source>
        <translation>Esikatselu</translation>
    </message>
</context>
</TS>
